@@ -614,6 +614,33 @@
     return NO;
   
   /* poll socket for input */
+#if 1
+  {
+    struct pollfd pfd;
+    int ret, timeout = 5;
+    pfd.fd = self->fd;
+    pfd.events = POLLIN;
+
+    while (YES) {
+      ret = poll(&pfd, 1, timeout);
+      if (ret >= 0)
+        break;
+
+      switch (errno) {
+      case EINTR:
+        continue;
+      default:
+        NSLog(@"socket poll() failed: %s", strerror(errno));
+        goto notAlive;
+      }
+    }
+
+    /* no input is pending, connection is alive */
+    if (!(pfd.revents & POLLIN)) {
+      return YES;
+    }
+  }
+#else
   {
     struct timeval to;
     fd_set readMask;
@@ -629,8 +656,6 @@
       switch (errno) {
         case EINTR:
           continue;
-        case EBADF:
-          goto notAlive;
         default:
           NSLog(@"socket select() failed: %s", strerror(errno));
           goto notAlive;
@@ -641,6 +666,7 @@
     if (!FD_ISSET(self->fd, &readMask)) 
       return YES;
   }
+#endif
 
   /*
     input is pending: If select() indicates pending input, but ioctl()
@@ -667,7 +693,7 @@
   close(self->fd);
 #endif
   self->fd = NGInvalidSocketDescriptor;
-  RELEASE(self->remoteAddress); self->remoteAddress = nil;
+  DESTROY(self->remoteAddress);
   return NO;
 }
  
